# ski

A Python package for solving an inventory control problem, retailing skis (Eric V. Denardo[1982]), with Markov Decision Process (MDP), Monte Carlo method (MC), Temporal Difference On-policy method (SARSA), and Temporal Difference Off-policy method (Q-learning)

Please feel free to visit [here](https://github.com/papillonbee/ski/blob/master/ski_0_0_27.ipynb) to see the manual